/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/* This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2009 Novell, Inc.
 */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <glib/gi18n.h>
#include <gtk/gtk.h>
#include <moblin-panel/mpl-panel-common.h>
#include <moblin-panel/mpl-panel-gtk.h>
#include "nmn-applet.h"
#include "nmn-icon-cache.h"
#include "utils.h"

int
main (int argc, char *argv[])
{
    MplPanelClient *panel_client;
    NmnApplet *applet;
    gboolean standalone = FALSE;
    GError *error = NULL;
    GOptionEntry    entries[] = {
        { "standalone", 's', 0, G_OPTION_ARG_NONE, &standalone, _("Run in standalone mode"), NULL }, { NULL }
    };

    bindtextdomain (GETTEXT_PACKAGE, NMNLOCALEDIR);
    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
    textdomain (GETTEXT_PACKAGE);

    g_set_application_name (_("NetworkManager Netbook"));
    gtk_init_with_args (&argc, &argv, _("- NetworkManager Netbook"),
			entries, GETTEXT_PACKAGE, &error);

    if (error) {
	g_printerr ("%s\n", error->message);
	g_error_free (error);
	return 1;
    }

    /* Force to the moblin theme */
    gtk_settings_set_string_property (gtk_settings_get_default (),
                                      "gtk-theme-name",
                                      "Moblin-Netbook",
                                      NULL);

    if (standalone) {
	GtkWidget *window;
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	g_signal_connect (window, "delete-event", (GCallback) gtk_main_quit,
			  NULL);
	applet = nmn_applet_new_standalone (GTK_WINDOW (window));
	gtk_widget_set_size_request (window, 1000, -1);
	utils_set_main_widget (G_OBJECT (window));
	gtk_widget_show (window);
    } else {
	panel_client = mpl_panel_gtk_new (MPL_PANEL_NETWORK,
					  _("network"),
					  THEME_PATH "/network-manager-netbook.css",
					  "unknown",
					  TRUE);

	mpl_panel_client_set_height_request (panel_client, 499);
	applet = nmn_applet_new (panel_client);
	utils_set_main_widget (G_OBJECT (panel_client));
    }

    gtk_main ();

    g_object_unref (applet);
    nmn_icon_cache_invalidate ();

    return 0;
}
