/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/* This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2009 Novell, Inc.
 */

#ifndef NMN_DEVICE_HANDLER_H
#define NMN_DEVICE_HANDLER_H

#include <glib-object.h>
#include <nm-device.h>
#include <nm-exported-connection.h>
#include "nmn-nm-data.h"
#include "nmn-network-item.h"

#define NMN_TYPE_DEVICE_HANDLER            (nmn_device_handler_get_type ())
#define NMN_DEVICE_HANDLER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NMN_TYPE_DEVICE_HANDLER, NmnDeviceHandler))
#define NMN_DEVICE_HANDLER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NMN_TYPE_DEVICE_HANDLER, NmnDeviceHandlerClass))
#define NMN_IS_DEVICE_HANDLER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NMN_TYPE_DEVICE_HANDLER))
#define NMN_IS_DEVICE_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), NMN_TYPE_DEVICE_HANDLER))
#define NMN_DEVICE_HANDLER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NMN_TYPE_DEVICE_HANDLER, NmnDeviceHandlerClass))

#define NMN_DEVICE_HANDLER_NM_DATA "nm-data"
#define NMN_DEVICE_HANDLER_DEVICE "device"

typedef struct {
    GObject parent;
} NmnDeviceHandler;

typedef struct {
    GObjectClass parent;

    /* methods */
    void (*connection_added) (NmnDeviceHandler *self,
                              NMSettingsConnectionInterface *connection);

    /* signals */
    void (*item_added) (NmnDeviceHandler *self,
                        NmnNetworkItem *item);
} NmnDeviceHandlerClass;

GType nmn_device_handler_get_type (void);

void nmn_device_handler_start (NmnDeviceHandler *self);
void nmn_device_handler_add_items (NmnDeviceHandler *self);
NmnNMData *nmn_device_handler_get_nm_data (NmnDeviceHandler *self);
NMDevice *nmn_device_handler_get_device (NmnDeviceHandler *self);

void nmn_device_handler_add_item (NmnDeviceHandler *self,
                                  NmnNetworkItem *item);

GSList *nmn_device_handler_get_items (NmnDeviceHandler *self);
GSList *nmn_device_handler_get_connections (NmnDeviceHandler *self);

NmnNetworkItem *nmn_device_handler_get_item_for_connection (NmnDeviceHandler *self,
                                                            NMSettingsConnectionInterface *connection);

void nmn_device_handler_remove_items (NmnDeviceHandler *self);

#endif /* NMN_DEVICE_HANDLER_H */
