/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/* This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2009 Novell, Inc.
 */

#include <gtk/gtk.h>
#include "nmn-item.h"

enum {
    PRIORITY_CHANGED,
    REMOVE_REQUESTED,

    LAST_SIGNAL
};

static guint signals[LAST_SIGNAL] = { 0 };

void
nmn_item_set_name (NmnItem *item,
                   const char *name)
{
    g_return_if_fail (NMN_IS_ITEM (item));

    g_object_set (item, NMN_ITEM_NAME, name, NULL);
}

char *
nmn_item_get_name (NmnItem *item)
{
    char *name;

    g_return_val_if_fail (NMN_IS_ITEM (item), NULL);

    name = NULL;
    g_object_get (item, NMN_ITEM_NAME, &name, NULL);

    return name;
}

void
nmn_item_set_priority (NmnItem *item,
                       guint priority)
{
    g_return_if_fail (NMN_IS_ITEM (item));

    g_object_set (item, NMN_ITEM_PRIORITY, priority, NULL);
}

guint
nmn_item_get_priority (NmnItem *item)
{
    guint priority;

    g_return_val_if_fail (NMN_IS_ITEM (item), G_MAXUINT);

    priority = 0;
    g_object_get (item, NMN_ITEM_PRIORITY, &priority, NULL);

    return priority;
}

void
nmn_item_remove_requested (NmnItem *item)
{
    g_return_if_fail (NMN_IS_ITEM (item));

    g_signal_emit (item, signals[REMOVE_REQUESTED], 0);
}

/*****************************************************************************/

static void
nmn_item_init (gpointer g_iface)
{
    GType iface_type = G_TYPE_FROM_INTERFACE (g_iface);
    static gboolean initialized = FALSE;

    if (initialized)
        return;

    /* Properties */
    g_object_interface_install_property
        (g_iface,
         g_param_spec_string (NMN_ITEM_NAME,
                              "Name",
                              "Name",
                              NULL,
                              G_PARAM_READWRITE));

    g_object_interface_install_property
        (g_iface,
         g_param_spec_uint (NMN_ITEM_PRIORITY,
                            "Priority",
                            "Item priority",
                            0, G_MAXUINT, 0,
                            G_PARAM_READABLE));

    /* Signals */
    signals[REMOVE_REQUESTED] = g_signal_new 
        ("remove-requested",
         iface_type,
         G_SIGNAL_RUN_LAST,
         G_STRUCT_OFFSET (NmnItem, remove_requested),
         NULL, NULL,
         g_cclosure_marshal_VOID__VOID,
         G_TYPE_NONE, 0);

    initialized = TRUE;
}

GType
nmn_item_get_type (void)
{
    static GType type = 0;

    if (!G_UNLIKELY (type)) {
        const GTypeInfo info = {
            sizeof (NmnItem), /* class_size */
            nmn_item_init,   /* base_init */
            NULL,       /* base_finalize */
            NULL,
            NULL,       /* class_finalize */
            NULL,       /* class_data */
            0,
            0,              /* n_preallocs */
            NULL
        };

        type = g_type_register_static (G_TYPE_INTERFACE,
                                       "NmnItem",
                                       &info, 0);

        g_type_interface_add_prerequisite (type, GTK_TYPE_WIDGET);
    }

    return type;
}
