/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/* This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2009 Novell, Inc.
 */

#ifndef NMN_NETWORK_ITEM_H
#define NMN_NETWORK_ITEM_H

#include <gtk/gtk.h>
#include <dbus/dbus-glib.h>
#include <nm-settings-connection-interface.h>
#include "nmn-item.h"
#include "nmn-connection-details.h"
#include "nmn-nm-data.h"

#define NMN_TYPE_NETWORK_ITEM            (nmn_network_item_get_type ())
#define NMN_NETWORK_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NMN_TYPE_NETWORK_ITEM, NmnNetworkItem))
#define NMN_NETWORK_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NMN_TYPE_NETWORK_ITEM, NmnNetworkItemClass))
#define NMN_IS_NETWORK_ITEM(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NMN_TYPE_NETWORK_ITEM))
#define NMN_IS_NETWORK_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), NMN_TYPE_NETWORK_ITEM))
#define NMN_NETWORK_ITEM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NMN_TYPE_NETWORK_ITEM, NmnNetworkItemClass))

#define NMN_NETWORK_ITEM_NM_DATA    "nm-data"
#define NMN_NETWORK_ITEM_DEVICE     "device"
#define NMN_NETWORK_ITEM_CONNECTION "connection"
#define NMN_NETWORK_ITEM_AC         "active-connection"
#define NMN_NETWORK_ITEM_TYPE_STRING "type-string"

typedef enum {
    NMN_NETWORK_ITEM_STATUS_DISCONNECTED,
    NMN_NETWORK_ITEM_STATUS_CONNECTING,
    NMN_NETWORK_ITEM_STATUS_CONNECTED
} NmnNetworkItemStatus;

typedef struct {
    GtkEventBox parent;
} NmnNetworkItem;

typedef struct {
    GtkEventBoxClass parent;

    /* Methods */
    void (*connect) (NmnNetworkItem *self);
    void (*disconnect) (NmnNetworkItem *self);
    guint (*get_priority) (NmnNetworkItem *self);
    const char * (*get_specific_object) (NmnNetworkItem *self);
    void (*secrets_requested) (NmnNetworkItem *self,
                               const char *setting_name,
                               const char **hints,
                               gboolean ask_user,
                               DBusGMethodInvocation *context);

    /* Signals */
    void (*connect_requested) (NmnNetworkItem *self);
    void (*disconnect_requested) (NmnNetworkItem *self);
    void (*delete) (NmnNetworkItem *self);
} NmnNetworkItemClass;

GType nmn_network_item_get_type (void);

void                 nmn_network_item_set_status_visible     (NmnNetworkItem *self,
                                                              gboolean visible);

void                  nmn_network_item_set_status            (NmnNetworkItem *self,
                                                              NmnNetworkItemStatus status);

NmnNetworkItemStatus  nmn_network_item_get_status            (NmnNetworkItem *self);
void                  nmn_network_item_set_icon              (NmnNetworkItem *self,
                                                              const char *icon_name);

void                  nmn_network_item_set_security          (NmnNetworkItem *self,
                                                              const char *security_string);

void                  nmn_network_item_set_delete_visible    (NmnNetworkItem *self,
                                                              gboolean visible);

void                  nmn_network_item_connect_request       (NmnNetworkItem *self);
void                  nmn_network_item_disconnect_request    (NmnNetworkItem *self);
gboolean              nmn_network_item_has_details           (NmnNetworkItem *self);
NmnConnectionDetails *nmn_network_item_get_details           (NmnNetworkItem *self);
NmnNMData            *nmn_network_item_get_nm_data           (NmnNetworkItem *self);
NMDevice             *nmn_network_item_get_device            (NmnNetworkItem *self);
NMSettingsConnectionInterface *nmn_network_item_get_connection (NmnNetworkItem *self);
void                  nmn_network_item_set_connection        (NmnNetworkItem *self,
                                                              NMSettingsConnectionInterface *connection);

NMActiveConnection   *nmn_network_item_get_active_connection (NmnNetworkItem *self);
void                  nmn_network_item_set_active_connection (NmnNetworkItem *self,
                                                              NMActiveConnection *ac);

#endif /* NMN_NETWORK_ITEM_H */
