/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/* This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2009 Novell, Inc.
 */

#include <glib/gi18n.h>
#include "nmn-text-item.h"
#include "nmn-item.h"

static void item_init (NmnItem *item_class);

G_DEFINE_TYPE_EXTENDED (NmnTextItem, nmn_text_item, GTK_TYPE_LABEL, 0,
                        G_IMPLEMENT_INTERFACE (NMN_TYPE_ITEM, item_init))

GtkWidget *
nmn_text_item_new (const char *text)
{
    return GTK_WIDGET (g_object_new (NMN_TYPE_TEXT_ITEM,
                                     NMN_ITEM_NAME, text,
                                     NULL));
}

static void
item_init (NmnItem *item_class)
{
}

static void
nmn_text_item_init (NmnTextItem *self)
{
    gtk_misc_set_alignment (GTK_MISC (self), 0.0, 0.5);
    gtk_misc_set_padding (GTK_MISC (self), 20, 20);
}

static void
set_property (GObject *object, guint prop_id,
              const GValue *value, GParamSpec *pspec)
{
    char *s;

    switch (prop_id) {
    case NMN_ITEM_PROP_NAME:
        /* FIXME: This does not belong here */
        s = g_strdup_printf ("<big><b>%s</b></big>", g_value_get_string (value));
        gtk_label_set_markup (GTK_LABEL (object), s);
        g_free (s);
        g_object_notify (object, NMN_ITEM_NAME);
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
        break;
   }
}

static void
get_property (GObject *object, guint prop_id,
              GValue *value, GParamSpec *pspec)
{
    switch (prop_id) {
    case NMN_ITEM_PROP_NAME:
        g_value_set_string (value, gtk_label_get_text (GTK_LABEL (object)));
        break;
    case NMN_ITEM_PROP_PRIORITY:
        g_value_set_uint (value, 0);
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
        break;
   }
}

static void
nmn_text_item_class_init (NmnTextItemClass *class)
{
    GObjectClass *object_class = G_OBJECT_CLASS (class);

    object_class->set_property = set_property;
    object_class->get_property = get_property;

    /* properties */
    g_object_class_override_property (object_class,
                                      NMN_ITEM_PROP_NAME,
                                      NMN_ITEM_NAME);

    g_object_class_override_property (object_class,
                                      NMN_ITEM_PROP_PRIORITY,
                                      NMN_ITEM_PRIORITY);
}
